@@ -37,10 +37,11 @@ Interacts
 """
 
 from traitlets import Bool, Int, Float, Unicode, Dict, Instance, List, TraitError
+from traittypes import Array
 from ipywidgets import Widget, Color, widget_serialization
 
 from .scales import Scale, DateScale
-from .traits import Date, NdArray
+from .traits import Date, array_serialization
 from .marks import Lines, Scatter
 
 
@@ -119,14 +120,8 @@ class HandDraw(Interaction):
     lines = Instance(Lines, allow_none=True, default_value=None).tag(sync=True, **widget_serialization)
     line_index = Int().tag(sync=True)
     # TODO: Handle infinity in a meaningful way (json does not)
-    min_x = (
-            Float(None, allow_none=True).tag(sync=True) |
-            Date(None, allow_none=True).tag(sync=True)
-        )
-    max_x = (
-            Float(None, allow_none=True).tag(sync=True) |
-            Date(None, allow_none=True).tag(sync=True)
-        )
+    min_x = (Float(None, allow_none=True) | Date(None, allow_none=True)).tag(sync=True)
+    max_x = (Float(None, allow_none=True) | Date(None, allow_none=True)).tag(sync=True)
 
     _view_name = Unicode('HandDraw').tag(sync=True)
     _model_name = Unicode('HandDrawModel').tag(sync=True)
@@ -259,13 +254,13 @@ class FastIntervalSelector(OneDSelector):
     ----------
     selected: numpy.ndarray
         Two-element array containing the start and end of the interval selected
-        in terms of the scale of the selector. This is a read-only attribute.
+        in terms of the scale of the selector.
     color: Color or None (default: None)
         color of the rectangle representing the interval selector
     size: Float or None (default: None)
         if not None, this is the fixed pixel-width of the interval selector
     """
-    selected = NdArray().tag(sync=True)
+    selected = Array(None, allow_none=True).tag(sync=True, **array_serialization)
     color = Color(None, allow_none=True).tag(sync=True)
     size = Float(None, allow_none=True).tag(sync=True)
 
@@ -299,7 +294,7 @@ class IndexSelector(OneDSelector):
     line_width: nonnegative integer (default: 0)
         Width of the line represetning the index selector.
     """
-    selected = NdArray().tag(sync=True)
+    selected = Array(None, allow_none=True).tag(sync=True, **array_serialization)
     line_width = Int(2).tag(sync=True)
     color = Color(None, allow_none=True).tag(sync=True)
 
@@ -327,7 +322,7 @@ class BrushIntervalSelector(OneDSelector):
     ----------
     selected: numpy.ndarray
         Two element array containing the start and end of the interval selected
-        in terms of the scale of the selector. This is a read-only attribute.
+        in terms of the scale of the selector.
         This attribute changes while the selection is being made with the
         ``BrushIntervalSelector``.
     brushing: bool
@@ -340,7 +335,7 @@ class BrushIntervalSelector(OneDSelector):
         Color of the rectangle representing the brush selector.
     """
     brushing = Bool().tag(sync=True)
-    selected = NdArray().tag(sync=True)
+    selected = Array(None, allow_none=True).tag(sync=True, **array_serialization)
     color = Color(None, allow_none=True).tag(sync=True)
 
     _view_name = Unicode('BrushIntervalSelector').tag(sync=True)
@@ -367,7 +362,7 @@ class BrushSelector(TwoDSelector):
     ----------
     selected: numpy.ndarray
         Two element array containing the start and end of the interval selected
-        in terms of the scales of the selector. This is a read-only attribute.
+        in terms of the scales of the selector.
         This attribute changes while the selection is being made with the
         ``BrushIntervalSelector``.
     brushing: bool (default: False)
@@ -520,8 +515,7 @@ class LassoSelector(TwoDSelector):
     color: Color (default: None)
         Color of the lasso.
     """
-    marks = List(Instance(Lines) | Instance(Scatter)).tag(sync=True,
-                 **widget_serialization)
+    marks = List(Instance(Lines) | Instance(Scatter)).tag(sync=True, **widget_serialization)
     color = Color(None, allow_none=True).tag(sync=True)
 
     def __init__(self, marks=None, **kwargs):
