@@ -36,11 +36,13 @@ Marks
 """
 from ipywidgets import Widget, DOMWidget, CallbackDispatcher, Color, widget_serialization
 from traitlets import (
-        Int, Unicode, List, Enum, Dict, Bool, Float, TraitError, Instance, Tuple
+        Int, Unicode, List, Enum, Dict, Bool, Float, Instance, Tuple,
+        TraitError, validate
     )
+from traittypes import Array
 
 from .scales import Scale, OrdinalScale
-from .traits import NdArray, Date
+from .traits import Date, array_serialization, array_squeeze, array_dimension_bounds
 
 from .colorschemes import CATEGORY10
 
@@ -184,7 +186,8 @@ class Mark(Widget):
                 )
             ]
 
-    def _scales_validate(self, scales, scales_trait):
+    @validate('scales')
+    def _validate_scales(self, proposal):
         """
         Validates the `scales` based on the mark's scaled attributes metadata.
 
@@ -193,6 +196,7 @@ class Mark(Widget):
         # Validate scales' 'rtype' versus data attribute 'rtype' decoration
         # At this stage it is already validated that all values in self.scales
         # are instances of Scale.
+        scales = proposal.value
         for name in self.trait_names(scaled=True):
             trait = self.traits()[name]
             if name not in scales:
@@ -207,9 +211,6 @@ class Mark(Widget):
                                      name)
         return scales
 
-    def _selected_default(self):
-        return None
-
     def __init__(self, **kwargs):
         super(Mark, self).__init__(**kwargs)
         self._hover_handlers = CallbackDispatcher()
@@ -306,7 +307,7 @@ class Lines(Mark):
         abscissas of the data points (1d or 2d array)
     y: numpy.ndarray (default: [])
         ordinates of the data points (1d or 2d array)
-    color: numpy.ndarray (default: [])
+    color: numpy.ndarray (default: None)
         colors of the different lines based on data. If it is [], then the
         colors from the colors attribute are used. Each line has a single color
         and if the size of colors is less than the number of lines, the
@@ -329,12 +330,9 @@ class Lines(Mark):
     name = 'Lines'
 
     # Scaled attributes
-    x = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=2,
-                scaled=True, rtype='Number', atype='bqplot.Axis')
-    y = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=2,
-                scaled=True, rtype='Number', atype='bqplot.Axis')
-    color = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                    rtype='Color', atype='bqplot.ColorAxis', min_dim=1, max_dim=1)
+    x = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 2))
+    y = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 2))
+    color = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Color', atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
 
     # Other attributes
     scales_metadata = Dict({
@@ -344,8 +342,7 @@ class Lines(Mark):
     }).tag(sync=True)
     colors = List(trait=Color(default_value=None, allow_none=True),
                   default_value=CATEGORY10).tag(sync=True, display_name='Colors')
-    fill_colors = List(trait=Color(default_value=None, allow_none=True),
-                       default_value=[]).tag(sync=True, display_name='Fill colors')
+    fill_colors = List(trait=Color(default_value=None, allow_none=True)).tag(sync=True, display_name='Fill colors')
     stroke_width = Float(2.0).tag(sync=True, display_name='Stroke width')
     labels_visibility = Enum(['none', 'label'], default_value='none').tag(sync=True, display_name='Labels visibility')
     curves_subset = List().tag(sync=True)
@@ -392,9 +389,9 @@ class FlexLine(Mark):
         abscissas of the data points (1d array)
     y: numpy.ndarray (default: [])
         ordinates of the data points (1d array)
-    color: numpy.ndarray or None (default: [])
+    color: numpy.ndarray or None (default: None)
         Array controlling the color of the data points
-    width: numpy.ndarray or None (default: [])
+    width: numpy.ndarray or None (default: None)
         Array controlling the widths of the Lines.
     """
     # Mark decoration
@@ -402,10 +399,10 @@ class FlexLine(Mark):
     name = 'Flexible lines'
 
     # Scaled attributes
-    x = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=1, scaled=True, rtype='Number', atype='bqplot.Axis')
-    y = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=1, scaled=True, rtype='Number', atype='bqplot.Axis')
-    color = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True, rtype='Color', atype='bqplot.ColorAxis')
-    width = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True, rtype='Number')
+    x = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    y = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    color = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Color', atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze)
+    width = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Number', **array_serialization).valid(array_squeeze)
 
     # Other attributes
     scales_metadata = Dict({
@@ -454,10 +451,24 @@ class Scatter(Mark):
         Default marker size in pixel.
         If size data is provided with a scale, default_size stands for the
         maximal marker size (i.e. the maximum value for the 'size' scale range)
-    names: numpy.ndarray (default: [])
+    drag_size: nonnegative float (default: 5.)
+        Ratio of the size of the dragged scatter size to the default scatter size.
+    names: numpy.ndarray (default: None)
         Labels for the points of the chart
     display_names: bool (default: True)
         Controls whether names are displayed for points in the scatter
+    enable_move: bool (default: False)
+        Controls whether points can be moved by dragging. Refer to restrict_x,
+        restrict_y for more options.
+    restrict_x: bool (default: False)
+        Restricts movement of the point to only along the x axis. This is valid
+        only when enable_move is set to True. If both restrict_x and restrict_y
+        are set to True, the point cannot be moved.
+    restrict_y: bool (default: False)
+        Restricts movement of the point to only along the y axis. This is valid
+        only when enable_move is set to True. If both restrict_x and restrict_y
+        are set to True, the point cannot be moved.
+
 
     Data Attributes
 
@@ -465,19 +476,19 @@ class Scatter(Mark):
         abscissas of the data points (1d array)
     y: numpy.ndarray (default: [])
         ordinates of the data points (1d array)
-    color: numpy.ndarray or None (default: [])
+    color: numpy.ndarray or None (default: None)
         color of the data points (1d array). Defaults to default_color when not
         provided or when a value is NaN
-    opacity: numpy.ndarray or None (default: [])
+    opacity: numpy.ndarray or None (default: None)
         opacity of the data points (1d array). Defaults to default_opacity when
         not provided or when a value is NaN
-    size: numpy.ndarray or None (default: [])
+    size: numpy.ndarray or None (default: None)
         size of the data points. Defaults to default_size when not provided or
         when a value is NaN
-    skew: numpy.ndarray or None (default: [])
+    skew: numpy.ndarray or None (default: None)
         skewness of the markers representing the data points. Defaults to
         default_skew when not provided or when a value is NaN
-    rotation: numpy.ndarray or None (default: [])
+    rotation: numpy.ndarray or None (default: None)
         orientation of the markers representing the data points.
         The rotation scale's range is [0, 180]
         Defaults to 0 when not provided or when a value is NaN.
@@ -499,20 +510,13 @@ class Scatter(Mark):
     name = 'Scatter'
 
     # Scaled attribtes
-    x = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=1, scaled=True,
-                rtype='Number', atype='bqplot.Axis')
-    y = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=1,
-                scaled=True, rtype='Number', atype='bqplot.Axis')
-    color = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                    rtype='Color', atype='bqplot.ColorAxis', min_dim=1, max_dim=1)
-    opacity = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                      rtype='Number', min_dim=1, max_dim=1)
-    size = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                   rtype='Number', min_dim=1, max_dim=1)
-    skew = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True, rtype='Number',
-                   min_dim=1, max_dim=1)
-    rotation = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                       rtype='Number', min_dim=1, max_dim=1)
+    x = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    y = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_dimension_bounds(1, 1))
+    color = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Color', atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    opacity = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    size = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    skew = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    rotation = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
     hovered_style = Dict().tag(sync=True)
     unhovered_style = Dict().tag(sync=True)
     hovered_point = Int(None, allow_none=True).tag(sync=True)
@@ -537,10 +541,11 @@ class Scatter(Mark):
     default_skew = Float(0.5, min=0, max=1).tag(sync=True)
     default_size = Int(64).tag(sync=True, display_name='Default size')
 
-    names = NdArray(squeeze=True).tag(sync=True)
+    names = Array(None, allow_none=True).tag(sync=True, **array_serialization).valid(array_squeeze)
     display_names = Bool(True).tag(sync=True, display_name='Display names')
     fill = Bool(True).tag(sync=True)
     drag_color = Color(None, allow_none=True).tag(sync=True)
+    drag_size = Float(5.).tag(sync=True)
     names_unique = Bool(True).tag(sync=True)
 
     enable_move = Bool().tag(sync=True)
@@ -613,7 +618,7 @@ class Hist(Mark):
 
     Data Attributes
 
-    sample: numpy.ndarray
+    sample: numpy.ndarray (default: [])
         sample of which the histogram must be computed.
     count: numpy.ndarray (read-only)
         number of sample points per bin. It is a read-only attribute.
@@ -632,15 +637,9 @@ class Hist(Mark):
     name = 'Histogram'
 
     # Scaled attributes
-    sample = NdArray(default_value=[], squeeze=True).tag(
-                sync=True, min_dim=1, max_dim=1, display_name='Sample',
-                scaled=True, rtype='Number', atype='bqplot.Axis')
-    count = NdArray(read_only=True, squeeze=True).tag(
-                sync=True, display_name='Count', scaled=True,
-                rtype='Number', atype='bqplot.Axis')
-    normalized = Bool(default_value=False).tag(sync=True)
-    # FIXME: Should we allow None for count?
-    # count is a read-only attribute that is set when the mark is drawn
+    sample = Array([]).tag(sync=True, display_name='Sample', scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    count = Array([], read_only=True).tag(sync=True, display_name='Count', scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze)
+    normalized = Bool().tag(sync=True)
 
     # Other attributes
     scales_metadata = Dict({
@@ -679,11 +678,9 @@ class Boxplot(Mark):
 
     Data Attributes
 
-    _y_default: numpy.ndarray
-        default 2 dimensional value for y
-    x: numpy.ndarray
+    x: numpy.ndarray (default: [])
         abscissas of the data points (1d array)
-    y: numpy.ndarray
+    y: numpy.ndarray (default: [[]])
         Sample data points (2d array)
     """
 
@@ -692,13 +689,10 @@ class Boxplot(Mark):
     name = 'Boxplot chart'
 
     # Scaled attributes
-    x = NdArray(default_value=[], squeeze=True).tag(
-            sync=True, scaled=True, rtype='Number', min_dim=1, max_dim=1, atype='bqplot.Axis')
+    x = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
 
-    # Second dimension must contain OHLC data, otherwise the behavior is
-    # undefined.
-    y = NdArray(default_value=[], squeeze=True).tag(
-            sync=True, scaled=True, rtype='Number', min_dim=1, max_dim=2, atype='bqplot.Axis')
+    # Second dimension must contain OHLC data, otherwise the behavior is undefined.
+    y = Array([[]]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_dimension_bounds(1, 2))
 
     # Other attributes
     scales_metadata = Dict({
@@ -757,11 +751,11 @@ class Bars(Mark):
 
     Data Attributes
 
-    x: numpy.ndarray
+    x: numpy.ndarray (default: [])
         abscissas of the data points (1d array)
-    y: numpy.ndarray
+    y: numpy.ndarray (default: [])
         ordinates of the values for the data points
-    color: numpy.ndarray
+    color: numpy.ndarray or None (default: None)
         color of the data points (1d array). Defaults to default_color when not
         provided or when a value is NaN
 
@@ -777,11 +771,9 @@ class Bars(Mark):
     name = 'Bar chart'
 
     # Scaled attributes
-    x = NdArray(default_value=[], squeeze=True).tag(sync=True, scaled=True, rtype='Number', min_dim=1, max_dim=1, atype='bqplot.Axis')
-    y = NdArray(default_value=[], squeeze=True).tag(sync=True, scaled=True, rtype='Number', min_dim=1, max_dim=2, atype='bqplot.Axis')
-    color = NdArray(None, allow_none=True, squeeze=True).tag(sync=True,
-                    scaled=True, rtype='Color', atype='bqplot.ColorAxis',
-                    min_dim=1, max_dim=1)
+    x = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    y = Array([]).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 2))
+    color = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Color', atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
 
     # Other attributes
     scales_metadata = Dict({
@@ -810,41 +802,65 @@ class Label(Mark):
 
     Attributes
     ----------
-    x: Date or float
-        horizontal position of the label, in data coordinates or in figure
-        coordinates
-    y: float or None (default: None)
-        vertical y position of the label, in data coordinates or in figure
-        coordinates
     x_offset: int (default: 0)
         horizontal offset in pixels from the stated x location
     y_offset: int (default: 0)
         vertical offset in pixels from the stated y location
-    color: Color or None (default: None)
-        label color
-    rotate_angle: float (default: 0.0)
-        angle by which the text is to be rotated
     text: string (default: '')
         text to be displayed
     font_size: string (default: '14px')
         font size in px, em or ex
     font_weight: {'bold', 'normal', 'bolder'}
         font weight of the caption
+    drag_size: nonnegative float (default: 1.)
+        Ratio of the size of the dragged label font size to the default label font size.
     align: {'start', 'middle', 'end'}
         alignment of the text with respect to the provided location
-    enable_move: Bool
-        Enable the label to be moved by dragging
+    enable_move: Bool (default: False)
+        Enable the label to be moved by dragging. Refer to restrict_x,
+        restrict_y for more options.
+    restrict_x: bool (default: False)
+        Restricts movement of the label to only along the x axis. This is valid
+        only when enable_move is set to True. If both restrict_x and restrict_y
+        are set to True, the label cannot be moved.
+    restrict_y: bool (default: False)
+        Restricts movement of the label to only along the y axis. This is valid
+        only when enable_move is set to True. If both restrict_x and restrict_y
+        are set to True, the label cannot be moved.
+
+    Data Attributes
+
+    x: numpy.ndarray (default: [])
+        horizontal position of the labels, in data coordinates or in figure coordinates
+    y: numpy.ndarray (default: [])
+        vertical position of the labels, in data coordinates or in figure coordinates
+    color: numpy.ndarray or None (default: None)
+        label colors
+    size: numpy.ndarray or None (default: None)
+        label sizes
+    rotation: numpy.ndarray or None (default: None)
+        label rotations
+    opacity: numpy.ndarray or None (default: None)
+        label opacities
+
     """
-    x = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=1, atype='bqplot.Axis')
-    y = NdArray(default_value=[], squeeze=True).tag(sync=True, min_dim=1, max_dim=1, atype='bqplot.Axis')
-    color = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                rtype='Color', atype='bqplot.ColorAxis', min_dim=1, max_dim=1)
-    size = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                   rtype='Number', min_dim=1, max_dim=1)
-    rotation = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                       rtype='Number', min_dim=1, max_dim=1)
-    opacity = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                      rtype='Number', min_dim=1, max_dim=1)
+    # Mark decoration
+    icon = 'fa-font'
+    name = 'Labels'
+
+    # Scaled attributes
+    x = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    y = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    color = Array(None, allow_none=True).tag(sync=True, scaled=True,
+                rtype='Color', atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    size = Array(None, allow_none=True).tag(sync=True, scaled=True,
+                   rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    rotation = Array(None, allow_none=True).tag(sync=True, scaled=True,
+                       rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    opacity = Array(None, allow_none=True).tag(sync=True, scaled=True,
+                      rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+
+    # Other attributes
     x_offset = Int().tag(sync=True)
     y_offset = Int().tag(sync=True)
     scales_metadata = Dict({
@@ -855,8 +871,9 @@ class Label(Mark):
     colors = List(trait=Color(default_value=None, allow_none=True), default_value=CATEGORY10).tag(sync=True, display_name='Colors')
     default_opacities = List(trait=Float(1.0, min=0, max=1, allow_none=True)).tag(sync=True, display_name='Opacities')
     rotate_angle = Float().tag(sync=True)
-    text = NdArray(squeeze=True).tag(sync=True)
+    text = Array(None, allow_none=True).tag(sync=True, **array_serialization).valid(array_squeeze)
     font_size = Float(16.).tag(sync=True)
+    drag_size = Float(1.).tag(sync=True)
     font_unit = Enum(['px', 'em', 'pt', '%'], default_value='px').tag(sync=True)
     font_weight = Enum(['bold', 'normal', 'bolder'], default_value='bold').tag(sync=True)
     align = Enum(['start', 'middle', 'end'], default_value='start').tag(sync=True)
@@ -925,11 +942,9 @@ class OHLC(Mark):
 
     Data Attributes
 
-    _y_default: numpy.ndarray
-        default 2 dimensional value for y
     x: numpy.ndarray
         abscissas of the data points (1d array)
-    y: numpy.ndarray
+    y: numpy.ndarrays
         Open/High/Low/Close ordinates of the data points (2d array)
 
     Notes
@@ -948,12 +963,10 @@ class OHLC(Mark):
     name = 'OHLC chart'
 
     # Scaled attributes
-    x = NdArray(default_value=[], squeeze=True).tag(sync=True, scaled=True,
-                rtype='Number', min_dim=1, max_dim=1, atype='bqplot.Axis')
-    y = NdArray(default_value=[[]]).tag(sync=True, scaled=True,
-                rtype='Number', min_dim=2, max_dim=2, atype='bqplot.Axis')
-    # FIXME Future warnings
-    _y_default = None
+    x = Array([]).tag(sync=True, scaled=True,
+                rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    y = Array([[]]).tag(sync=True, scaled=True,
+                rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_dimension_bounds(1, 2))
 
     # Other attributes
     scales_metadata = Dict({
@@ -1013,11 +1026,10 @@ class Pie(Mark):
 
     Data Attributes
 
-    sizes: numpy.ndarray
+    sizes: numpy.ndarray (default: [])
         proportions of the pie slices
-    color: numpy.ndarray or None
-        color of the data points (1d array). Defaults to colors when not
-        provided
+    color: numpy.ndarray or None (default: None)
+        color of the data points. Defaults to colors when not provided.
 
     Notes
     -----
@@ -1034,13 +1046,12 @@ class Pie(Mark):
     name = 'Pie chart'
 
     # Scaled attributes
-    sizes = NdArray(default_value=[], squeeze=True).tag(sync=True, rtype='Number', min_dim=1, max_dim=1)
-    color = NdArray(allow_none=True, squeeze=True).tag(sync=True, scaled=True, rtype='Color',
-                          atype='bqplot.ColorAxis', min_dim=1, max_dim=1)
+    sizes = Array([]).tag(sync=True, rtype='Number', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    color = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Color', atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
 
     # Other attributes
-    x = Float(0.5).tag(sync=True) | Date().tag(sync=True) | Unicode().tag(sync=True)
-    y = Float(0.5).tag(sync=True) | Date().tag(sync=True) | Unicode().tag(sync=True)
+    x = (Float(0.5) | Date() | Unicode()).tag(sync=True)
+    y = (Float(0.5) | Date() | Unicode()).tag(sync=True)
 
     scales_metadata = Dict({'color': {'dimension': 'color'}}).tag(sync=True)
     sort = Bool().tag(sync=True)
@@ -1133,7 +1144,7 @@ class Map(Mark):
         'selected_stroke_width': 2.0
     }).tag(sync=True)
 
-    map_data = Tuple(topo_load('map_data/WorldMapData.json')).tag(sync=True)
+    map_data = Dict(topo_load('map_data/WorldMap.json')).tag(sync=True)
 
     _view_name = Unicode('Map').tag(sync=True)
     _model_name = Unicode('MapModel').tag(sync=True)
@@ -1177,10 +1188,10 @@ class GridHeatMap(Mark):
 
     Data Attributes
 
-    color: numpy.ndarray
+    color: numpy.ndarray or None (default: None)
         color of the data points (2d array). The number of elements in this array
         correspond to the number of cells created in the heatmap.
-    row: numpy.ndarray or None
+    row: numpy.ndarray or None (default: None)
         labels for the rows of the `color` array passed. The length of this can be
         no more than 1 away from the number of rows in `color`.
         This is a scaled attribute and can be used to affect the height of the
@@ -1188,7 +1199,7 @@ class GridHeatMap(Mark):
         of the cells. Refer to the property `row_align`.
         If this prorety is None, then a uniformly spaced grid is generated in
         the row direction.
-    column: numpy.ndarray or None
+    column: numpy.ndarray or None (default: None)
         labels for the columns of the `color` array passed. The length of this can be
         no more than 1 away from the number of columns in `color`
         This is a scaled attribute and can be used to affect the width of the
@@ -1198,12 +1209,12 @@ class GridHeatMap(Mark):
         the column direction.
     """
     # Scaled attributes
-    row = NdArray(allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                  rtype='Number', min_dim=1, max_dim=1, atype='bqplot.Axis')
-    column = NdArray(allow_none=True, squeeze=True).tag(sync=True, scaled=True,
-                     rtype='Number', min_dim=1, max_dim=1, atype='bqplot.Axis')
-    color = NdArray(None, allow_none=True, squeeze=True).tag(sync=True, scaled=True, rtype='Color',
-                    atype='bqplot.ColorAxis', min_dim=1, max_dim=2)
+    row = Array(None, allow_none=True).tag(sync=True, scaled=True,
+                  rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    column = Array(None, allow_none=True).tag(sync=True, scaled=True,
+                     rtype='Number', atype='bqplot.Axis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 1))
+    color = Array(None, allow_none=True).tag(sync=True, scaled=True, rtype='Color',
+                    atype='bqplot.ColorAxis', **array_serialization).valid(array_squeeze, array_dimension_bounds(1, 2))
 
     # Other attributes
     scales_metadata = Dict({
