@@ -141,6 +141,7 @@ def figure(key=None, fig=None, **kwargs):
     this figure becomes the current context figure.
 
     Otherwise:
+
     - If no key is provided, a new empty context figure is created.
     - If a key is provided for which a context already exists, the
       corresponding context becomes current.
@@ -156,6 +157,7 @@ def figure(key=None, fig=None, **kwargs):
         Any variable that can be used as a key for a dictionary
     fig: Figure, optional
         A bqplot Figure
+
     """
     scales_arg = kwargs.pop('scales', {})
     _context['current_key'] = key
@@ -369,6 +371,28 @@ def grids(fig=None, value='solid'):
         a.grid_lines = value
 
 
+def title(label, style=None):
+    """Sets the title for the current figure.
+
+    Parameters
+    ----------
+    label : str
+        The new title for the current figure.
+    style: dict
+        The CSS style to be applied to the figure title
+    """
+    fig = current_figure()
+    fig.title = label
+    if style is not None:
+        fig.title_style = style
+
+
+def legend():
+    """Places legend in the current figure."""
+    for m in current_figure().marks:
+        m.display_legend = True
+
+
 def hline(level, fig=None, **kwargs):
     """Draws a horizontal line at the given level.
 
